==> oto-service-api-0.0.11-20221205.074745-10-sources.jar: cn/com/duiba/oto/dto/oto/cust/OtoCustomerExtDto.java <==
package cn.com.duiba.oto.dto.oto.cust;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * OTO客户信息扩展表
 * @author kjj mybatis generator 
 * @date 2022-01-11
 */
@Data
public class OtoCustomerExtDto implements Serializable {
     
    private static final long serialVersionUID = 16418803615184972L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 客户id tb_oto_customer.id
     */
    private Long custId;
    /**
     * 客户id tb_oto_customer.id
     */
    private List<Long> custIds;

    /**
     * 加微状态  0:未主动发起加微 1:已主动添加-对方没反应 2:已主动添加-对方拒绝 3:已主动添加-对方已同意
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustWxStatusEnum
     */
    private Integer addWxStatus;

    /**
     * 核心决策人 0:不明或其他 1:本人或配偶 2:子女 3：父母
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustCoreMakerEnum
     */
    private String coreMaker;

    /**
     * 参观进度 0：无参观意向 1：未参观-有参观意向 2：已预约参观时间 3：完成参观
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustVisitProgressEnum
     */
    private Integer visitProgress;

    /**
     * 为谁考虑(多选) 0:自己 1：父母 2:其他 3家人
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustForWhoEnum
     */
    private String forWho;

    /**
     * 入住人出生年份
     */
    private Integer roomerBirthYear;

    /**
     * 入住人城市
     */
    private String roomerCity;

    /**
     * 考虑原因 0刚需 1未来 2了解一下
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustReasonEnum
     */
    private Integer considerReason;

    /**
     * 付费压力 0有压力 1略有压力 2无压力
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustPressureEnum
     */
    private Integer payPressure;

    /**
     * 退休金 0:0-5000 1:5000-8000 2: 8000-12000 3：12000+
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustRetireMoneyEnum
     */
    private Integer retireMoney;

    /**
     * 参观机构（多选） 0：国寿 1:泰康 2太平 3:其他
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustVisitOrgEnum
     */
    private String visitOrg;

    /**
     * 资金情况 0:不详 1:无资金 2:资金已到位 3:资金近期到位 4:资金明年到位
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustMoneyEnum
     */
    private Integer hasMoney;

    /**
     * 房产情况
     */
    private Integer hasHouse;

    /**
     * 家人态度 0未商量过 1支持 2反对
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustFamilyAttitudeEnum
     */
    private Integer familyAttitude;

    /**
     * 理念是否认同 0不认同 1认同
     * @see cn.com.duiba.kjy.base.api.enums.BooleanEnum
     */
    private Integer ideaAgree;

    /**
     * 专家对应的销售ID
     */
    private Long expertSellerId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 是否可送计划书 0否 1是
     */
    private Integer giveProspectusFlag;

    /**
     * 计划书金额
     */
    private String prospectusAmount;

    /**
     * 计划书确认情况
     */
    private String prospectusDesc;

    /**
     * 专家备注
     */
    private String expertRemark;

    /**
     * 是否提交养老计划方案
     *
     * @see cn.com.duiba.kjy.base.api.enums.BooleanEnum
     */
    private Integer commitPlanFlag;

    private Long otoSid;

    private Boolean optFlag = false;

    /**
     * 重点跟进人
     */
    private String followUp;
}

==> oto-service-api-0.0.17-20230110.062326-10-sources.jar: cn/com/duiba/oto/dto/oto/cust/OtoCustomerExtDto.java <==
package cn.com.duiba.oto.dto.oto.cust;

import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * OTO客户信息扩展表
 * @author kjj mybatis generator 
 * @date 2022-01-11
 */
@Data
public class OtoCustomerExtDto implements Serializable {
     
    private static final long serialVersionUID = 16418803615184972L;

    /**
     * 主键
     */
    private Long id;

    /**
     * 客户id tb_oto_customer.id
     */
    private Long custId;
    /**
     * 客户id tb_oto_customer.id
     */
    private List<Long> custIds;

    /**
     * 加微状态  0:未主动发起加微 1:已主动添加-对方没反应 2:已主动添加-对方拒绝 3:已主动添加-对方已同意
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustWxStatusEnum
     */
    private Integer addWxStatus;

    /**
     * 核心决策人 0:不明或其他 1:本人或配偶 2:子女 3：父母
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustCoreMakerEnum
     */
    private String coreMaker;

    /**
     * 参观进度 0：无参观意向 1：未参观-有参观意向 2：已预约参观时间 3：完成参观
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustVisitProgressEnum
     */
    private Integer visitProgress;

    /**
     * 为谁考虑(多选) 0:自己 1：父母 2:其他 3家人
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustForWhoEnum
     */
    private String forWho;

    /**
     * 入住人出生年份
     */
    private Integer roomerBirthYear;

    /**
     * 入住人城市
     */
    private String roomerCity;

    /**
     * 考虑原因 0刚需 1未来 2了解一下
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustReasonEnum
     */
    private Integer considerReason;

    /**
     * 付费压力 0有压力 1略有压力 2无压力
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustPressureEnum
     */
    private Integer payPressure;

    /**
     * 退休金 0:0-5000 1:5000-8000 2: 8000-12000 3：12000+
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustRetireMoneyEnum
     */
    private Integer retireMoney;

    /**
     * 参观机构（多选） 0：国寿 1:泰康 2太平 3:其他
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustVisitOrgEnum
     */
    private String visitOrg;

    /**
     * 资金情况 0:不详 1:无资金 2:资金已到位 3:资金近期到位 4:资金明年到位
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustMoneyEnum
     */
    private Integer hasMoney;

    /**
     * 房产情况
     */
    private Integer hasHouse;

    /**
     * 家人态度 0未商量过 1支持 2反对
     * @see cn.com.duiba.oto.enums.cust.ext.OtoCustFamilyAttitudeEnum
     */
    private Integer familyAttitude;

    /**
     * 理念是否认同 0不认同 1认同
     * @see cn.com.duiba.kjy.base.api.enums.BooleanEnum
     */
    private Integer ideaAgree;

    /**
     * 专家对应的销售ID
     */
    private Long expertSellerId;

    /**
     * 创建时间
     */
    private Date gmtCreate;

    /**
     * 是否可送计划书 0否 1是
     */
    private Integer giveProspectusFlag;

    /**
     * 计划书金额
     */
    private String prospectusAmount;

    /**
     * 计划书确认情况
     */
    private String prospectusDesc;

    /**
     * 专家备注
     */
    private String expertRemark;

    /**
     * 是否提交养老计划方案
     *
     * @see cn.com.duiba.kjy.base.api.enums.BooleanEnum
     */
    private Integer commitPlanFlag;

    private Long otoSid;

    private Boolean optFlag = false;

    /**
     * 重点跟进人
     */
    private String followUp;

    /**
     * 促单标记
     */
    private Integer promotionType;

    /**
     * 促单时间
     */
    private Date promotionTime;

    /**
     * kyc图片
     */
    private String kycImage;

    /**
     * 方案地址
     */
    private String planFile;
}
